function _aws_cdk_aws_iotevents_actions_SetVariableAction(p) {
}
function _aws_cdk_aws_iotevents_actions_LambdaInvokeAction(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_iotevents_actions_SetVariableAction, _aws_cdk_aws_iotevents_actions_LambdaInvokeAction };
module.exports.DeprecationError = DeprecationError;
